---
---

# HAWCsat Simulator Package

The `hawcsimulator` package provides functionality for simulating observations from the
ALI and SHOW instruments planned to be part of the HAWCsat satellite.



```{toctree}
:maxdepth: 4
:hidden:
:caption: For Users

installation
quickstart
changelog
```

```{toctree}
:maxdepth: 4
:hidden:
:caption: The SHOW Simulator

show/introduction.md
show/quickstart.md
```

```{toctree}
:maxdepth: 4
:hidden:
:caption: The ALI Simulator

ali/introduction.md
ali/quickstart.md
```

```{toctree}
:maxdepth: 4
:hidden:
:caption: API Reference

api/steps.md
api/datacontainers.md
```

```{toctree}
:maxdepth: 4
:hidden:
:caption: For Developers

developer/local_setup.md
developer/contributing.md
```
